#line 2 "scanner.cc"

#line 4 "scanner.cc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 84
#define YY_END_OF_BUFFER 85
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[672] =
    {   0,
        6,    6,   85,    6,   83,   84,    1,    6,   83,   84,
        2,   84,    6,   83,   84,    6,   83,   84,    6,   83,
       84,    6,   23,   83,   84,    6,   83,   84,    6,   14,
       83,   84,    6,   15,   83,   84,    7,   21,   83,   84,
        6,   17,   83,   84,    6,   20,   83,   84,    6,   18,
       83,   84,    6,   28,   83,   84,    6,   83,   84,    6,
       69,   79,   83,   84,    6,   78,   83,   84,    6,   16,
       83,   84,    6,   22,   83,   84,    6,   24,   83,   84,
        6,   27,   83,   84,    6,   25,   83,   84,    6,   72,
       83,   84,    6,   72,   83,   84,    6,   72,   83,   84,

        6,   72,   83,   84,    6,   72,   83,   84,    6,   30,
       83,   84,    6,   31,   83,   84,    6,   72,   83,   84,
        6,   72,   83,   84,    6,   72,   83,   84,    6,   72,
       83,   84,    6,   72,   83,   84,    6,   72,   83,   84,
        6,   72,   83,   84,    6,   72,   83,   84,    6,   72,
       83,   84,    6,   72,   83,   84,    6,   72,   83,   84,
        6,   72,   83,   84,    6,   72,   83,   84,    6,   72,
       83,   84,    6,   72,   83,   84,    6,   12,   83,   84,
        5,   13,   83,   84,    6,   19,   83,   84,    6,    6,
       34,    6,    6,   82,    6,    6,   11,    6,    9,    6,

        6,    6,    4,    6,   32,    6,    6,   76,    3,    6,
        8,    6,    6,   79,    6,    6,    6,   69,    6,   80,
        6,   78,    6,   78,    6,   26,    6,   33,    6,   72,
        6,   72,    6,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,   72,    6,   72,    6,   72,
       82,    6,    6,    6,    9,    9,    6,    6,   81,   81,

        6,   81,    6,    6,    6,   29,    6,    6,    8,    8,
        6,   75,    6,    6,   74,    6,   80,    6,   72,    6,
       72,    6,   72,    6,   72,    6,   72,    6,   72,    6,
       72,    6,   72,    6,   72,    6,   72,    6,   72,    6,
       72,    6,   72,    6,   58,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,    6,    6,    6,    6,    6,
        6,   77,    6,    6,   72,    6,   72,    6,   72,    6,

       72,    6,   61,   72,    6,   59,   72,    6,   72,    6,
       72,    6,   36,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,   72,    6,   50,   72,    6,   72,    6,
       72,    6,   72,    6,   72,    6,   72,    6,   72,    6,
       72,    6,   72,    6,   72,    6,   72,    6,   72,    6,
       72,    6,   57,   72,    6,   72,    6,   72,    6,   72,
        6,   72,    6,    6,    6,    6,    6,    6,   73,    6,
       62,   72,    6,   72,    6,   72,    6,   72,    6,   39,
       72,    6,   35,   72,    6,   72,    6,   60,   72,    6,
       72,    6,   72,    6,   72,    6,   72,    6,   72,    6,

       72,    6,   72,    6,   72,    6,   72,    6,   72,    6,
       49,   72,    6,   72,    6,   72,    6,   56,   72,    6,
       72,    6,   72,    6,   72,    6,   72,    6,   38,   72,
        6,   72,    6,    6,   66,   72,    6,   72,    6,   72,
        6,   72,    6,   51,   72,    6,   44,   72,    6,   63,
       72,    6,   72,    6,   72,    6,   72,    6,   72,    6,
       72,    6,   43,   72,    6,   55,   72,    6,   72,    6,
       47,   72,    6,   45,   72,    6,   40,   72,    6,   72,
        6,   72,    6,   72,    6,    6,   72,    6,   72,    6,
        6,   72,    6,   46,   72,    6,   72,    6,   72,    6,

       53,   72,    6,   72,    6,   54,   72,    6,   65,   72,
        6,   72,    6,   42,   72,    6,    6,   67,   72,    6,
       72,    6,   70,    6,   70,    6,   72,    6,   72,    6,
       41,   72,    6,   72,    6,   48,   72,    6,    6,    6,
       68,   72,    6,    6,   72,    6,   37,   72,    6,   52,
       72,    6,   11,    6,    6,   71,    6,   72,   10,   11,
        6,    6,   72,   10,    6,   72,    6,   72,    6,   64,
       72
    } ;

static yyconst flex_int16_t yy_accept[320] =
    {   0,
        1,    2,    3,    4,    7,   11,   13,   16,   19,   22,
       26,   29,   33,   37,   41,   45,   49,   53,   57,   60,
       65,   69,   73,   77,   81,   85,   89,   93,   97,  101,
      105,  109,  113,  117,  121,  125,  129,  133,  137,  141,
      145,  149,  153,  157,  161,  165,  169,  173,  177,  181,
      185,  189,  190,  192,  193,  195,  195,  196,  197,  198,
      200,  200,  201,  202,  202,  203,  204,  206,  207,  209,
      210,  212,  213,  215,  216,  217,  219,  221,  223,  225,
      227,  229,  231,  233,  235,  237,  239,  241,  243,  245,
      247,  249,  251,  253,  255,  257,  259,  261,  263,  265,

      267,  269,  271,  273,  275,  277,  279,  281,  283,  285,
      287,  289,  291,  292,  292,  293,  294,  296,  297,  298,
      300,  301,  303,  304,  305,  307,  308,  310,  311,  313,
      314,  316,  318,  320,  322,  324,  326,  328,  330,  332,
      334,  336,  338,  340,  342,  344,  347,  349,  351,  353,
      355,  357,  359,  361,  363,  365,  367,  369,  371,  373,
      375,  377,  379,  381,  383,  385,  385,  385,  386,  387,
      388,  389,  390,  391,  393,  394,  396,  398,  400,  402,
      405,  408,  410,  412,  415,  417,  419,  421,  423,  425,
      428,  430,  432,  434,  436,  438,  440,  442,  444,  446,

      448,  450,  452,  455,  457,  459,  461,  463,  463,  463,
      464,  465,  466,  467,  468,  470,  473,  475,  477,  479,
      482,  485,  487,  490,  492,  494,  496,  498,  500,  502,
      504,  506,  508,  510,  513,  515,  517,  520,  522,  524,
      526,  528,  531,  533,  533,  533,  534,  537,  539,  541,
      543,  546,  549,  552,  554,  556,  558,  560,  562,  565,
      568,  570,  573,  576,  579,  581,  583,  585,  586,  588,
      590,  591,  593,  596,  598,  600,  603,  605,  608,  611,
      613,  616,  617,  620,  622,  624,  625,  626,  628,  630,
      633,  635,  638,  639,  640,  643,  644,  646,  649,  652,

      653,  654,  655,  655,  657,  659,  659,  659,  661,  662,
      662,  664,  665,  665,  665,  667,  669,  672,  672
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    7,    1,    1,    8,    9,   10,
       11,   12,   13,   14,   15,   16,   17,   18,   19,   19,
       19,   19,   19,   19,   19,   20,   20,   21,   22,   23,
       24,   25,   26,    1,   27,   28,   29,   30,   31,   32,
       33,   33,   33,   34,   35,   36,   33,   33,   37,   38,
       39,   40,   41,   42,   43,   33,   33,   44,   33,   33,
       45,   46,   47,    1,   48,    1,   49,   50,   51,   52,

       53,   54,   55,   56,   57,   33,   58,   59,   60,   61,
       62,   63,   33,   64,   65,   66,   67,   68,   33,   69,
       70,   33,   71,    1,   72,   73,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[74] =
    {   0,
        1,    2,    3,    4,    1,    5,    1,    1,    5,    1,
        1,    6,    1,    1,    1,    1,    1,    7,    7,    8,
        1,    1,    1,    1,    1,    5,    8,    8,    8,    8,
        8,    8,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    9,    1,    5,    1,    4,    7,    7,
        8,    8,    8,    7,    4,    4,    4,    4,    4,    4,
        9,    4,    4,    9,    4,    9,    4,    9,    9,    4,
        1,   10,    1
    } ;

static yyconst flex_int16_t yy_base[337] =
    {   0,
        0,    0,  923,    0,    0, 1107,  898,   72,   74,    0,
       73,    0,    0,  904,    0,    0,  894,   71,   64,   79,
       85,  894,    0,   69,  890,   82,  148,  221,   61,   69,
       73,    0,    0,   81,   53,   75,   67,   93,   98,   84,
      139,  115,  120,  148,  140,  141,  149,  150,    0, 1107,
        0,    0,    0,  206,    0,  174,  289,  178, 1107,  179,
      910,  197,  903,  902,  353, 1107,    0,  894,  243, 1107,
      114,  115,  257,  266,  286,    0,  405,  293,    0,    0,
        0,  882,  100,  162,  176,  156,  190,  175,  222,  226,
      188,  213,  230,  233,  264,  189,  232,  237,  212,  227,

      275,  290,  254,  238,  287,  256,  299,  289,  298,  295,
      294,  300, 1107,  326,  372,  442,  370,  905,  377,    0,
     1107,  898,  357,  479,    0,  368,  322,    0,  432,  349,
      386,    0,  229,  320,  102,  304,  365,  301,  350,  366,
      325,  373,  374,  385,  383,  878,  402,  386,  371,  437,
      381,  400,  382,  384,  419,  403,  420,  438,  439,  448,
      449,  450,  455,  452,  451,  508,    0,  532,  603,  477,
      528,  667,  500,  503,  540,  456,  498,  514,  473,  877,
      876,  497,  513,  875,  512,  489,  516,  525,  518,  874,
      534,  529,  536,  538,  530,  539,  537,  540,  542,  543,

      541,  546,  864,  547,  545,  548,  544,  601,  716,  612,
      634,  578,  881,  607,  619,  862,  555,  457,  583,  848,
      847,  601,  843,  561,  589,  585,  602,  614,  616,  617,
      637,  638,  632,  841,  633,  639,  840,  651,  624,  647,
      640,  839,  654,  662,  663,  660,  838,  644,  680,  700,
      837,  835,  678,  686,  688,  652,  696,  697,  834,  832,
      706,  830,  829,  823,  698,  701,  683,  726,  713,  724,
      798,  723,  814,  729,  714,  809,  704,  808,  800,  731,
      799,  770,  764,  733,  871,  701,    0,  732,  734,  643,
      750,  575,  826,  828,  565,  583,  737,  309,  158,  848,

      173,  783,  791,    0,  757,  775,  351, 1107,  834,  782,
      790, 1107,  787,  793,  774,  798,   56, 1107,  944,  953,
      963,  973,  983,  992, 1002, 1012, 1022, 1028, 1037, 1047,
     1051, 1059, 1067, 1076, 1086, 1096
    } ;

static yyconst flex_int16_t yy_def[337] =
    {   0,
      318,    1,  318,  319,  319,  318,  319,  320,  321,  319,
      322,  319,  319,  318,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  323,  323,   28,   28,
       28,  319,  319,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,  319,  318,
      319,  319,  319,  320,  319,  324,  319,  321,  318,  325,
      326,  321,  319,  318,  319,  318,  319,  319,  319,  318,
      327,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,

       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,  318,  328,  320,  319,  325,  329,  321,  319,
      318,  319,  319,  319,  319,  319,  327,  330,  319,  319,
      319,   77,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,  324,  331,  320,  320,  321,
      319,  319,  319,  319,  319,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,

       28,   28,   28,   28,   28,   28,   28,  324,  324,  320,
      320,  321,  319,  319,  319,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,  324,  324,  321,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,  321,   28,   28,
      332,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,  321,   28,   28,  332,  319,  333,   28,   28,   28,
       28,   28,  321,  334,   28,  319,   28,   28,   28,  334,

      335,  321,  336,  319,   28,  335,  318,  318,  321,  326,
       28,  318,  318,  326,   28,   28,   28,    0,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318
    } ;

static yyconst flex_int16_t yy_nxt[1181] =
    {   0,
        4,    5,    6,    5,    7,    8,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   21,
       22,   23,   24,   25,   26,    4,   27,   27,   27,   27,
       27,   28,   27,   27,   29,   27,   27,   27,   30,   27,
       27,   31,   27,   27,   32,    4,   33,   27,   27,   27,
       34,   27,   35,   36,   27,   27,   37,   38,   39,   40,
       41,   42,   43,   44,   45,   46,   47,   48,   27,   27,
       49,   50,   51,   52,   52,   70,   59,   55,   60,   82,
       71,   52,   82,   56,   64,   61,   68,   82,   69,   69,
       69,   81,   53,   82,   72,   82,   73,   73,   74,   82,

       72,   82,   78,   78,   78,   53,   81,   82,   84,   75,
       82,   86,   87,   91,   76,   75,   85,   57,   65,   82,
       79,   92,   77,   93,   82,  128,   82,   95,   82,  178,
       62,   75,  129,  129,  129,  133,   88,   75,   94,   89,
       96,   82,   90,   56,   64,   61,   82,   77,   52,   52,
       98,   52,   52,   52,   52,   52,   52,   52,   52,   97,
       52,   52,   52,   52,   52,   82,   82,   82,   52,   52,
       52,   52,   52,   52,   82,   82,   82,  100,  307,  113,
       59,   59,   82,  101,   82,  128,  102,   99,   82,   61,
      118,  134,   52,   52,   52,  104,  105,  307,  106,   59,

      103,   82,   82,  136,  108,  107,  112,   52,   61,  110,
      109,   55,  135,  111,   82,   82,   82,   56,   52,  114,
       52,   52,   52,  138,   52,   52,   52,   52,   52,   52,
       52,   52,  137,   52,   52,   52,   52,   52,   82,   82,
      147,   52,   52,   52,   52,   52,   52,   83,   82,   61,
      118,   57,   82,   82,  141,   82,   82,  119,   82,   82,
       69,   69,   69,   82,   82,   52,   52,   52,   61,  176,
      139,  150,   72,  126,   73,   73,   74,   56,  142,  151,
       82,   72,   82,   74,   74,   74,  140,   75,  143,  144,
       82,   52,  148,   52,   54,  126,   75,   54,  130,  156,

      130,   82,  149,  131,  131,  131,  115,  115,   72,   75,
       78,   78,   78,   82,   54,   82,   82,  158,   75,  155,
       82,   82,  145,   75,   82,   82,   82,   82,   79,  146,
       82,  152,  116,  128,   54,   82,  153,   54,   54,  154,
      179,  157,   54,  166,  166,   75,   82,  159,  177,   54,
      164,   82,   54,  312,   54,  161,   54,  116,   63,  163,
      162,  122,  160,  165,  181,  120,  131,  131,  131,  167,
      123,  123,   59,   52,  171,  171,   82,   55,   63,   59,
      173,  118,  173,   56,  184,  174,  174,  174,   61,  168,
      168,   82,   82,  128,  167,  180,  124,   82,   63,   82,

       82,   63,   63,  131,  131,  131,   63,   82,   82,   82,
       82,   82,   82,   63,  182,  313,   63,   57,   63,  191,
       63,  124,  132,  132,  132,  185,   82,  170,   82,   82,
      183,  132,  132,  132,  132,  132,  132,  187,  186,  188,
      190,  118,  196,   56,  193,   82,   82,  195,   61,  129,
      129,  129,  189,  132,  132,  132,  132,  132,  132,  169,
      169,  169,  175,   82,   82,   82,  198,  194,  169,  169,
      169,  169,  169,  169,   82,   82,   82,   82,   82,   59,
      199,   82,   82,   82,  175,  197,  216,  248,   61,  192,
      169,  169,  169,  169,  169,  169,  172,  172,  172,   82,

      219,  203,  204,  200,  201,  172,  172,  172,  172,  172,
      172,  205,  206,  113,  202,   82,  207,  174,  174,  174,
      174,  174,  174,   82,   82,  208,  208,  172,  172,  172,
      172,  172,  172,   52,  217,  212,  120,   55,   82,   82,
       82,  223,   82,   56,   82,   63,   63,  218,   61,  210,
      210,   82,  214,  114,  214,   82,   82,  215,  215,  215,
       82,  220,   82,   82,   82,   82,   82,   82,   82,   82,
       82,   82,   82,   82,   82,  222,  224,   57,  221,  226,
       59,   82,  231,  227,  229,  225,  230,   82,  304,   61,
      235,   82,  247,  228,  236,  232,  239,  238,  240,  241,

      233,   82,  242,   56,   52,  234,  113,  237,   55,   82,
      243,   82,  251,   52,   56,   82,  249,   55,  244,  244,
      211,  211,  211,   56,  215,  215,  215,   82,   82,  211,
      211,  211,  211,  211,  211,   52,  215,  215,  215,   55,
       82,  252,   82,   82,  246,   56,  114,  253,   57,   61,
       82,  211,  211,  211,  211,  211,  211,   57,   82,   82,
      254,  250,   59,   82,   82,   82,   82,  113,  113,   82,
       82,   61,  269,   82,   56,  120,  255,   82,   82,   57,
       82,  256,  257,   56,  213,  213,  213,  258,  259,  264,
      262,  261,  260,  213,  213,  213,  213,  213,  213,  265,

      266,  263,  267,  271,   82,   56,   82,  114,  114,   82,
      270,  268,   82,  275,   82,  213,  213,  213,  213,  213,
      213,  113,   82,   82,   82,  272,   82,   82,   59,  296,
       82,   61,   82,  245,  245,  245,  274,   61,  273,   82,
       82,  281,  245,  245,  245,  245,  245,  245,  276,   82,
       82,  279,  284,  280,  283,   82,  291,   82,   82,   82,
       82,  114,  277,   82,  245,  245,  245,  245,  245,  245,
      278,  293,   59,  293,  295,  294,   82,  290,  282,  289,
      307,   61,  292,   82,  308,  308,  298,  288,  297,  312,
       82,  305,  294,  301,   61,  308,  310,   61,   52,  307,

       82,  299,   52,  286,   52,   52,   52,   52,   52,  287,
       52,   52,   52,   52,   52,  310,   82,  311,   52,   52,
       52,   52,   52,   52,   82,   82,   82,  293,   59,  293,
      301,  294,  316,  302,   82,   82,  308,   61,  315,  303,
       82,   61,   52,   52,   52,   61,  314,  309,  294,   82,
      301,  313,  302,  302,   61,   82,   82,  314,   82,  303,
       82,   82,  317,   82,   82,   82,   82,   82,   52,   82,
       52,   52,  302,   82,   82,   52,   52,   52,   52,   52,
       52,   52,  287,   52,   52,   52,   52,   52,   82,  120,
       82,   52,   52,   52,   52,   52,   52,   61,  309,  303,

       82,   82,   82,   82,   82,   61,  120,   59,   82,  125,
      121,  120,   59,   53,   80,   52,   52,   52,   67,  303,
       66,   53,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,   52,  318,   52,   52,   52,  318,   52,   52,  318,
       52,   52,   52,   54,   54,  318,   54,   54,   54,   54,
       54,   54,   54,   58,   58,   58,   58,   58,   58,   58,
       58,   58,   58,   63,   63,  318,   63,   63,   63,   63,
       63,   63,   63,   82,   82,  318,   82,   82,  318,   82,
       82,   82,   56,  318,  318,   56,   56,   56,   56,   56,

       56,   56,  117,  117,  117,  117,  117,  117,  117,  117,
      117,  117,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,  127,  127,  318,  127,  127,  127,  127,  127,
      127,  127,   56,  318,   56,  318,   56,  118,  118,  118,
      118,  118,  118,  118,  118,  118,  118,  128,  128,  318,
      128,  128,  128,  128,  128,  128,  128,  209,  209,  285,
      285,  318,  285,  285,  285,  285,  285,  285,  287,  318,
      287,  318,  287,  287,  287,  287,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  303,  303,  303,  303,

      303,  303,  303,  303,  303,  303,    3,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318
    } ;

static yyconst flex_int16_t yy_chk[1181] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    8,   11,   19,    9,    8,    9,   35,
       19,   11,  317,    8,   11,    9,   18,   29,   18,   18,
       18,   24,   24,   37,   20,   30,   20,   20,   20,   31,

       21,   36,   21,   21,   21,   26,   26,   34,   29,   20,
       40,   31,   31,   35,   20,   21,   30,    8,   11,   38,
       21,   35,   20,   36,   39,   71,   83,   37,  135,  135,
        9,   20,   72,   72,   72,   83,   34,   21,   36,   34,
       38,   42,   34,    8,   11,    9,   43,   20,   27,   27,
       40,   27,   27,   27,   27,   27,   27,   27,   27,   39,
       27,   27,   27,   27,   27,   41,   45,   46,   27,   27,
       27,   27,   27,   27,   44,   47,   48,   42,  301,   56,
       58,   60,   86,   43,  299,   71,   43,   41,   84,   58,
       60,   84,   27,   27,   27,   45,   45,  301,   45,   62,

       44,   88,   85,   86,   46,   45,   48,   54,   62,   47,
       46,   54,   85,   47,   91,   96,   87,   54,   27,   56,
       27,   28,   28,   88,   28,   28,   28,   28,   28,   28,
       28,   28,   87,   28,   28,   28,   28,   28,   99,   92,
       96,   28,   28,   28,   28,   28,   28,   28,   89,   58,
       60,   54,   90,  100,   91,  133,   93,   62,   97,   94,
       69,   69,   69,   98,  104,   28,   28,   28,   62,  133,
       89,   99,   73,   69,   73,   73,   73,   54,   92,  100,
      103,   74,  106,   74,   74,   74,   90,   73,   93,   94,
       95,   28,   97,   28,   57,   69,   74,   57,   75,  104,

       75,  101,   98,   75,   75,   75,   57,   57,   78,   73,
       78,   78,   78,  105,   57,  108,  102,  106,   74,  103,
      111,  110,   95,   78,  109,  107,  112,  138,   78,   95,
      136,  101,   57,  127,   57,  298,  101,   57,   57,  102,
      136,  105,   57,  114,  114,   78,  134,  107,  134,   57,
      111,  141,   57,  307,   57,  108,   57,   57,   65,  110,
      109,   65,  107,  112,  138,  123,  130,  130,  130,  114,
       65,   65,  117,  115,  123,  123,  139,  115,   65,  119,
      126,  117,  126,  115,  141,  126,  126,  126,  119,  115,
      115,  137,  140,  127,  114,  137,   65,  149,   65,  142,

      143,   65,   65,  131,  131,  131,   65,  151,  153,  145,
      154,  144,  148,   65,  139,  307,   65,  115,   65,  149,
       65,   65,   77,   77,   77,  142,  152,  119,  147,  156,
      140,   77,   77,   77,   77,   77,   77,  144,  143,  145,
      148,  117,  154,  115,  151,  155,  157,  153,  119,  129,
      129,  129,  147,   77,   77,   77,   77,   77,   77,  116,
      116,  116,  129,  150,  158,  159,  156,  152,  116,  116,
      116,  116,  116,  116,  160,  161,  162,  165,  164,  170,
      157,  163,  176,  218,  129,  155,  176,  218,  170,  150,
      116,  116,  116,  116,  116,  116,  124,  124,  124,  179,

      179,  161,  162,  158,  159,  124,  124,  124,  124,  124,
      124,  163,  164,  166,  160,  186,  165,  173,  173,  173,
      174,  174,  174,  182,  177,  166,  166,  124,  124,  124,
      124,  124,  124,  168,  177,  170,  171,  168,  185,  183,
      178,  186,  187,  168,  189,  171,  171,  178,  170,  168,
      168,  188,  175,  166,  175,  192,  195,  175,  175,  175,
      191,  182,  193,  197,  194,  196,  198,  201,  199,  200,
      207,  205,  202,  204,  206,  185,  187,  168,  183,  189,
      212,  217,  195,  191,  193,  188,  194,  224,  296,  212,
      199,  295,  217,  192,  199,  196,  202,  201,  204,  205,

      197,  292,  206,  168,  169,  198,  208,  200,  169,  219,
      207,  226,  224,  210,  169,  225,  219,  210,  208,  208,
      169,  169,  169,  210,  214,  214,  214,  222,  227,  169,
      169,  169,  169,  169,  169,  211,  215,  215,  215,  211,
      228,  225,  229,  230,  212,  211,  208,  226,  169,  212,
      239,  169,  169,  169,  169,  169,  169,  210,  233,  235,
      227,  222,  246,  231,  232,  236,  241,  244,  245,  290,
      248,  246,  248,  240,  169,  172,  228,  238,  256,  211,
      243,  229,  230,  210,  172,  172,  172,  231,  232,  239,
      236,  235,  233,  172,  172,  172,  172,  172,  172,  240,

      241,  238,  243,  250,  253,  211,  249,  244,  245,  267,
      249,  246,  254,  256,  255,  172,  172,  172,  172,  172,
      172,  209,  257,  258,  265,  253,  250,  266,  268,  286,
      277,  246,  261,  209,  209,  209,  255,  268,  254,  269,
      275,  267,  209,  209,  209,  209,  209,  209,  257,  272,
      270,  265,  270,  266,  269,  274,  277,  280,  288,  284,
      289,  209,  258,  297,  209,  209,  209,  209,  209,  209,
      261,  282,  282,  282,  284,  282,  291,  275,  268,  274,
      306,  282,  280,  305,  310,  302,  289,  272,  288,  313,
      283,  297,  282,  303,  302,  314,  303,  268,  271,  306,

      315,  291,  271,  271,  271,  271,  271,  271,  271,  271,
      271,  271,  271,  271,  271,  303,  311,  305,  271,  271,
      271,  271,  271,  271,  316,  281,  279,  293,  293,  293,
      294,  293,  315,  294,  278,  276,  309,  293,  311,  294,
      273,  282,  271,  271,  271,  309,  310,  302,  293,  264,
      300,  313,  294,  300,  302,  263,  262,  314,  260,  300,
      259,  252,  316,  251,  247,  242,  237,  234,  271,  223,
      271,  285,  300,  221,  220,  285,  285,  285,  285,  285,
      285,  285,  285,  285,  285,  285,  285,  285,  216,  213,
      203,  285,  285,  285,  285,  285,  285,  293,  309,  294,

      190,  184,  181,  180,  146,  309,  122,  118,   82,   68,
       64,   63,   61,   25,   22,  285,  285,  285,   17,  300,
       14,    7,    3,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  285,    0,  285,  319,  319,    0,  319,  319,    0,
      319,  319,  319,  320,  320,    0,  320,  320,  320,  320,
      320,  320,  320,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  322,  322,    0,  322,  322,  322,  322,
      322,  322,  322,  323,  323,    0,  323,  323,    0,  323,
      323,  323,  324,    0,    0,  324,  324,  324,  324,  324,

      324,  324,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  327,  327,    0,  327,  327,  327,  327,  327,
      327,  327,  328,    0,  328,    0,  328,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  330,  330,    0,
      330,  330,  330,  330,  330,  330,  330,  331,  331,  332,
      332,    0,  332,  332,  332,  332,  332,  332,  333,    0,
      333,    0,  333,  333,  333,  333,  334,  334,  334,  334,
      334,  334,  334,  334,  334,  334,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  336,  336,  336,  336,

      336,  336,  336,  336,  336,  336,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  318,  318,  318,  318
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scanner.ll"
#line 2 "scanner.ll"
/*****************************************************************
Copyright (c) 1999 Torben Weis <weis@kde.org>
Copyright (c) 2000 Matthias Ettrich <ettrich@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#define YY_NO_UNPUT
#include <stdlib.h>
#include <ctype.h>

class TQString;

#ifndef KDE_USE_FINAL
#include "yacc.cc.h"
#endif

extern int idl_line_no;
int comment_mode;
int function_mode = 0;

#include <tqstring.h>
#include <tqregexp.h>

static long ascii_to_longlong( long base, const char *s )
{
  long ll = 0;
  while( *s != '\0' ) {
    char c = *s++;
    if( c >= 'a' )
      c -= 'a' - 'A';
    c -= '0';
    if( c > 9 )
      c -= 'A' - '0' - 10;
    ll = ll * base + c;
  }
  return ll;
}

static double ascii_to_longdouble (const char *s)
{
  double d;
#ifdef HAVE_SCANF_LF
  sscanf (s, "%Lf", &d);
#else
  /*
   * this is only an approximation and will probably break fixed<>
   * parameter calculation on systems where
   * sizeof(double) < sizeof(long double). but fortunately all
   * systems where scanf("%Lf") is known to be broken (Linux/Alpha
   * and HPUX) have sizeof(double) == sizeof(long double).
   */
  d = strtod (s, NULL);
#endif
  return d;
}

static char translate_char( const char *s )
{
  char c = *s++;

  if( c != '\\' )
    return c;
  c = *s++;
  switch( c ) {
  case 'n':
    return '\n';
  case 't':
    return '\t';
  case 'v':
    return '\v';
  case 'b':
    return '\b';
  case 'r':
    return '\r';
  case 'f':
    return '\f';
  case 'a':
    return '\a';
  case '\\':
    return '\\';
  case '?':
    return '\?';
  case '\'':
    return '\'';
  case '"':
    return '"';
  case 'x':
  case 'X':
    return (char) ascii_to_longlong( 16, s );
  default:
    // Gotta be an octal
    return (char) ascii_to_longlong( 8, s );
  }
}


/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
#line 1030 "scanner.cc"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
#line 148 "scanner.ll"


#line 1220 "scanner.cc"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 319 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 318 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 150 "scanner.ll"
;
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 151 "scanner.ll"
{ idl_line_no++; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 153 "scanner.ll"
{ comment_mode = 1; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 154 "scanner.ll"
{ if (!comment_mode) { REJECT; } else { comment_mode = 0; } }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 155 "scanner.ll"
{   
		    if (! comment_mode) {
		    if (!function_mode) { REJECT; } else {
			function_mode = 0;
			return T_RIGHT_CURLY_BRACKET;
		    }
		    }
		}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 163 "scanner.ll"
{ if (!comment_mode && !function_mode) { REJECT; } }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 164 "scanner.ll"
{ if (!comment_mode) { REJECT; } }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 166 "scanner.ll"
;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 167 "scanner.ll"
{
                          exit( 1 );
                        }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 170 "scanner.ll"
{
			  TQString s( yytext );
                          int i = s.find(TQRegExp("[\"<]"))+1;
                          int j = s.find(TQRegExp("[\">]"), i);
			  yylval._str = new TQString( s.mid( i, j - i ) );
                          idl_line_no++;
                          return T_INCLUDE;
                        }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 178 "scanner.ll"
{
                          idl_line_no++;
                        }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 181 "scanner.ll"
return T_LEFT_CURLY_BRACKET;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 182 "scanner.ll"
return T_RIGHT_CURLY_BRACKET;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 183 "scanner.ll"
return T_LEFT_PARANTHESIS;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 184 "scanner.ll"
return T_RIGHT_PARANTHESIS;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 185 "scanner.ll"
return T_COLON;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 186 "scanner.ll"
return T_PLUS;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 187 "scanner.ll"
return T_MINUS;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 188 "scanner.ll"
return T_TILDE;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 189 "scanner.ll"
return T_COMMA;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 190 "scanner.ll"
return T_ASTERISK;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 191 "scanner.ll"
return T_SEMICOLON;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 192 "scanner.ll"
return T_AMPERSAND;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 193 "scanner.ll"
return T_LESS;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 194 "scanner.ll"
return T_GREATER;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 195 "scanner.ll"
return T_SCOPE;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 196 "scanner.ll"
return T_EQUAL;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 197 "scanner.ll"
return T_ACCESS;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 198 "scanner.ll"
return T_TRIPLE_DOT;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 199 "scanner.ll"
return T_ARRAY_OPEN;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 200 "scanner.ll"
return T_ARRAY_CLOSE;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 201 "scanner.ll"
return T_ACCESS;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 202 "scanner.ll"
return T_SHIFT;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 203 "scanner.ll"
return T_MISCOPERATOR;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 206 "scanner.ll"
return T_CONST;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 207 "scanner.ll"
return T_ENUM;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 208 "scanner.ll"
return T_NAMESPACE;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 209 "scanner.ll"
return T_USING;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 210 "scanner.ll"
return T_CLASS;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 211 "scanner.ll"
return T_STRUCT;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 212 "scanner.ll"
return T_FUNOPERATOR;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 213 "scanner.ll"
return T_VIRTUAL;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 214 "scanner.ll"
return T_PUBLIC;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 215 "scanner.ll"
return T_INLINE;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 216 "scanner.ll"
return T_STATIC;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 217 "scanner.ll"
return T_MUTABLE;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 218 "scanner.ll"
return T_SIGNED;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 219 "scanner.ll"
return T_UNSIGNED;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 220 "scanner.ll"
return T_SHORT;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 221 "scanner.ll"
return T_LONG;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 222 "scanner.ll"
return T_FRIEND;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 223 "scanner.ll"
return T_PROTECTED;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 224 "scanner.ll"
return T_PRIVATE;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 225 "scanner.ll"
return T_SIGNAL;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 226 "scanner.ll"
return T_RETURN;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 227 "scanner.ll"
return T_SLOT;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 228 "scanner.ll"
return T_TRUE;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 229 "scanner.ll"
return T_INT;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 230 "scanner.ll"
return T_CHAR;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 231 "scanner.ll"
return T_FALSE;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 232 "scanner.ll"
return T_TRUE;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 233 "scanner.ll"
return T_FALSE;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 234 "scanner.ll"
return T_DCOP_AREA;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 235 "scanner.ll"
return T_DCOP_SIGNAL_AREA;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 236 "scanner.ll"
return T_TYPEDEF;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 237 "scanner.ll"
return T_DCOP;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 238 "scanner.ll"
;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 239 "scanner.ll"
;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 240 "scanner.ll"
return T_NULL;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 241 "scanner.ll"
return T_EXTERN;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 242 "scanner.ll"
return T_EXTERN_C;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 244 "scanner.ll"
{
			  yylval._str = new TQString( yytext );
			  return T_IDENTIFIER;
			}
	YY_BREAK
case 73:
#line 250 "scanner.ll"
case 74:
#line 251 "scanner.ll"
case 75:
#line 252 "scanner.ll"
case 76:
#line 253 "scanner.ll"
case 77:
YY_RULE_SETUP
#line 253 "scanner.ll"
{
			  yylval._float = ascii_to_longdouble( yytext );
			  return T_DOUBLE_LITERAL;
			}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 257 "scanner.ll"
{
			  yylval._int = ascii_to_longlong( 10, yytext );
			  return T_INTEGER_LITERAL;
			}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 261 "scanner.ll"
{
			  yylval._int = ascii_to_longlong( 8, yytext );
			  return T_INTEGER_LITERAL;
			}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 265 "scanner.ll"
{
			  yylval._int = ascii_to_longlong( 16, yytext + 2 );
			  return T_INTEGER_LITERAL;
			}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 269 "scanner.ll"
{
                          TQCString s( yytext );
	                  s = s.mid( 1, s.length() - 2 );
			  yylval._char = translate_char( s );
			  return T_CHARACTER_LITERAL;
			}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 275 "scanner.ll"
{
                          TQString s( yytext );
                          yylval._str = new TQString( s.mid( 1, s.length() - 2 ) );
			  return T_STRING_LITERAL;
			}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 280 "scanner.ll"
{
			  if (function_mode)
				return yylex(); // call once again

			  tqFatal("could not parse %c(%d) at line %d" , yytext[0], yytext[0], idl_line_no);
			  return T_UNKNOWN;
			}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 288 "scanner.ll"
ECHO;
	YY_BREAK
#line 1771 "scanner.cc"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 319 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 319 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 318);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "[dcopidl-scanner] %s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 288 "scanner.ll"



void dcopidlInitFlex( const char *_code )
{
   comment_mode = 0;
   yy_switch_to_buffer(yy_scan_string(_code ) );
}

